@@ -337,8 +337,6 @@ do_open(GnomeVFSMethod *method,
 
 	/* handle the .directory file */
 	if (!strcmp(path, "/.directory")) {
-		GnomeVFSURI *uri;
-
 		uri = gnome_vfs_uri_new(THEME_METHOD_DIRECTORY);
 		result = gnome_vfs_open_uri_cancellable(
 			(GnomeVFSHandle **)method_handle, uri, mode, context);
@@ -478,7 +476,7 @@ do_seek(GnomeVFSMethod *method,
 static GnomeVFSResult
 do_tell(GnomeVFSMethod *method,
 	GnomeVFSMethodHandle *method_handle,
-	GnomeVFSFileOffset *offset_return)
+	GnomeVFSFileSize *offset_return)
 {
 	return gnome_vfs_tell(
 			(GnomeVFSHandle*)(((ThemeHandle*)(method_handle))->handle),
@@ -702,7 +700,7 @@ static GnomeVFSMethod method = {
 GnomeVFSMethod*
 vfs_module_init (const char *method_name, const char *args)
 {
-	gnome_theme_init (FALSE);
+	gnome_theme_init (NULL);
 	if (!strcmp (method_name, "themes"))
 	{
 		gnome_theme_info_register_theme_change ((GFunc)invoke_monitors, NULL);
